@@ -42,7 +42,8 @@ class BaseReader:
                     path,
                     pickleable=0,
                     formatting_info=1,
-                    on_demand=True),
+                    on_demand=True,
+                    ragged_rows=True),
                 os.path.split(path)[1]
                 )
 
@@ -62,7 +63,7 @@ class BaseReader:
                 filter.sheet(sheet,sheet.name)
                 for row_x in xrange(sheet.nrows):
                     filter.row(row_x,row_x)
-                    for col_x in xrange(sheet.ncols):
+                    for col_x in xrange(sheet.row_len(row_x)):
                         filter.cell(row_x,col_x,row_x,col_x)
                 if workbook.on_demand:
                     workbook.unload_sheet(sheet_x)
@@ -417,12 +418,13 @@ class BaseWriter:
         wtsheet.first_visible_row = rdsheet.first_visible_rowx
         wtsheet.first_visible_col = rdsheet.first_visible_colx
         wtsheet.grid_colour = rdsheet.gridline_colour_index
-        wtsheet.preview_magn = rdsheet.cached_page_break_preview_mag_factor
-        wtsheet.normal_magn = rdsheet.cached_normal_view_mag_factor
+        wtsheet.preview_magn = rdsheet.cooked_page_break_preview_mag_factor
+        wtsheet.normal_magn = rdsheet.cooked_normal_view_mag_factor
         #
         # DEFAULTROWHEIGHT
         #
-        wtsheet.row_default_height =          rdsheet.default_row_height
+        if rdsheet.default_row_height is not None:
+            wtsheet.row_default_height =          rdsheet.default_row_height
         wtsheet.row_default_height_mismatch = rdsheet.default_row_height_mismatch
         wtsheet.row_default_hidden =          rdsheet.default_row_hidden
         wtsheet.row_default_space_above =     rdsheet.default_additional_space_above
@@ -432,6 +434,17 @@ class BaseWriter:
         #
         wtsheet.visibility = rdsheet.visibility
        
+        #
+        # PANE
+        #
+        if rdsheet.has_pane_record:
+            wtsheet.split_position_units_are_twips = True
+            wtsheet.active_pane =              rdsheet.split_active_pane
+            wtsheet.horz_split_pos =           rdsheet.horz_split_pos
+            wtsheet.horz_split_first_visible = rdsheet.horz_split_first_visible
+            wtsheet.vert_split_pos =           rdsheet.vert_split_pos
+            wtsheet.vert_split_first_visible = rdsheet.vert_split_first_visible
+            
     def set_rdsheet(self,rdsheet):
         self.rdsheet = rdsheet
         
@@ -663,7 +676,7 @@ class ErrorFilter(BaseReader,BaseWriter):
             yield (
                 # We currently don't open with on_demand=True here
                 # as error filters should be lastish in the chain
-                # so there's no much win.
+                # so there's not much win.
                 # However, if we did, getting rid of the temp dirs
                 # becomes a problem as, on Windows, they can't be
                 # deleted until the xlrd.Book object is done with
@@ -672,7 +685,8 @@ class ErrorFilter(BaseReader,BaseWriter):
                     os.path.join(self.temp_path,pathname),
                     pickleable=0,
                     formatting_info=1,
-                    on_demand=False
+                    on_demand=False,
+                    ragged_rows=True
                     ),
                 filename
                 )
